Getting Started
===============

Getting the Code
----------------
As the code is not very mature, there is no package available. Currently the quickest way is to fork or clone from
GitHub.

You can find the source code here: https://github.com/egemenimre/satmad

Dependencies
------------
- NumPy and SciPy are used for the underlying mathematical algorithms
- Astropy handles all time and reference frame computations
- Portion handles the time interval mechanics
- python-sgp4 provides the TLE manipulation and SGP4 propagation engine
- Pytest provides the testing framework
